@@ -497,7 +497,7 @@ class MySQLCursor(CursorBase):
         if params is not None:
             if isinstance(params, dict):
                 for key, value in self._process_params_dict(params).items():
-                    stmt = stmt.replace(key, value, 1)
+                    stmt = stmt.replace(key, value)
             elif isinstance(params, (list, tuple)):
                 psub = _ParamSubstitutor(self._process_params(params))
                 stmt = RE_PY_PARAM.sub(psub, stmt)
@@ -552,7 +552,7 @@ class MySQLCursor(CursorBase):
                 tmp = fmt
                 if isinstance(params, dict):
                     for key, value in self._process_params_dict(params).items():
-                        tmp = tmp.replace(key, value, 1)
+                        tmp = tmp.replace(key, value)
                 else:
                     psub = _ParamSubstitutor(self._process_params(params))
                     tmp = RE_PY_PARAM.sub(psub, tmp)
@@ -604,6 +604,8 @@ class MySQLCursor(CursorBase):
             return
         if self._connection.unread_result is True:
             raise errors.InternalError("Unread result found.")
+        if isinstance(operation, bytes):
+            return self.execute(operation)
         if not isinstance(seq_params, (list, tuple)):
             raise errors.ProgrammingError(
                 "Parameters for query must be list or tuple.")
@@ -658,10 +660,23 @@ class MySQLCursor(CursorBase):
           END
 
           2) Executing in Python:
-          args = (5,5,0) # 0 is to hold pprod
+          args = (5, 5, 0)  # 0 is to hold pprod
           cursor.callproc('multiply', args)
           print(cursor.fetchone())
 
+        For OUT and INOUT parameters the user should provide the
+        type of the parameter as well. The argument should be a
+        tuple with first item as the value of the parameter to pass
+        and second argument the type of the argument.
+
+        In the above example, one can call callproc method like:
+          args = (5, 5, (0, 'INT'))
+          cursor.callproc('multiply', args)
+
+        The type of the argument given in the tuple will be used by
+        the MySQL CAST function to convert the values in the corresponding
+        MySQL type (See CAST in MySQL Reference for more information)
+
         Does not return a value, but a result set will be
         available when the CALL-statement execute successfully.
         Raises exceptions when something is wrong.
@@ -678,12 +693,18 @@ class MySQLCursor(CursorBase):
         results = []
         try:
             argnames = []
-
+            argtypes = []
             if args:
                 for idx, arg in enumerate(args):
                     argname = argfmt.format(name=procname, index=idx + 1)
                     argnames.append(argname)
-                    self.execute("SET {0}=%s".format(argname), (arg,))
+                    if isinstance(arg, tuple):
+                        argtypes.append(" CAST({0} AS {1})".format(
+                                                            argname, arg[1]))
+                        self.execute("SET {0}=%s".format(argname), (arg[0],))
+                    else:
+                        argtypes.append(argname)
+                        self.execute("SET {0}=%s".format(argname), (arg,))
 
             call = "CALL {0}({1})".format(procname, ','.join(argnames))
 
@@ -696,7 +717,7 @@ class MySQLCursor(CursorBase):
                     # pylint: enable=W0212
 
             if argnames:
-                select = "SELECT {0}".format(','.join(argnames))
+                select = "SELECT {0}".format(','.join(argtypes))
                 self.execute(select)
                 self._stored_results = results
                 return self.fetchone()
